pub struct TraceContext {
pub traceparent: String,
pub tracestate: Option<String>,
}Expand description
Origin and processing contexts have the same wire format but different lifetimes.
Fields
traceparent: Stringtracestate: Option<String>Implementations
Sourceimpl TraceContext
impl TraceContext
pub fn validate(&self) -> Result<()>
Sourcepub fn from_event(event: &CloudEvent) -> Option<Self>
pub fn from_event(event: &CloudEvent) -> Option<Self>
The immutable event creation context, never an active execution context.